FrAG-PELE: 
===========

A novel fragment-based growing tool for hit-to-lead in drug design

.. image:: docs/_images/movie_growing_phenyl.gif
    :height: 100px
    :width: 200 px
    :scale: 100%
    :align: center

Installation
=============

https://carlesperez94.github.io/frag_pele/installation.html

Getting Started:
=================

https://carlesperez94.github.io/frag_pele/first_steps.html

Cite 
====
.. image:: https://img.shields.io/badge/DOI-10.1021%2Facs.jcim.9b00938-blue.png
    :target: https://pubs.acs.org/doi/abs/10.1021/acs.jcim.9b00938

Perez Lopez, C.; Soler, D.; Soliva, R.; Guallar, V. FragPELE: Dynamic Ligand Growing within a Binding Site. A Novel Tool for Hit-to-Lead Drug Design. J. Chem. Inf. Model. 2020. https://doi.org/10.1021/acs.jcim.9b00938.
